@@ -158,10 +158,6 @@ class LambdaHandler:
         tx.table(helpers.get_tracking_table(user or self.session)).insert(data)
 
     def OnActionDefault(self, tx, context):
-        print("[ERROR] AWS_EVENT", str(self.aws_event))
-        print("[ERROR] AWS_EVENT", dir(self.aws_event))
-        print("[ERROR] AWS_EVENT", self.aws_event)
-
         context.response().set_body(
             {"event": self.aws_event, "postdata": context.postdata()}
         )
