@@ -52,3 +52,19 @@ class DbDataIntegrityError(DbException):
 
 class DuplicateRowsFoundError(Exception):
     pass
+
+
+class DbQueryError(DbException):
+    """Database query error"""
+    pass
+
+
+class DbTransactionError(DbException):
+    """Database transaction error"""
+    pass
+
+
+# Add aliases for backward compatibility with engine.py
+class DatabaseError(DbException):
+    """Generic database error - alias for DbException"""
+    pass
