@@ -1,4 +1,5 @@
 import pprint
+from velocity.db.exceptions import DbColumnMissingError
 
 
 class Row:
@@ -85,10 +86,21 @@ class Row:
         return list(d.items())
 
     def get(self, key, failobj=None):
-        data = self[key]
-        if data is None:
+        try:
+            data = self[key]
+            if data is None:
+                return failobj
+            return data
+        except DbColumnMissingError:
+            # Column doesn't exist in the table, return the default value
             return failobj
-        return data
+        except Exception as e:
+            # Check if the error message indicates a missing column
+            error_msg = str(e).lower()
+            if 'column' in error_msg and ('does not exist' in error_msg or 'not found' in error_msg):
+                return failobj
+            # Re-raise other exceptions
+            raise
 
     def setdefault(self, key, default=None):
         data = self[key]
