@@ -81,8 +81,8 @@ class Transaction:
                 cursor.execute(sql, parms)
             else:
                 cursor.execute(sql)
-        except:
-            self.engine.process_error(sql, parms)
+        except Exception as e:
+            raise self.engine.process_error(e, sql, parms)
 
         if single:
             self.connection.autocommit = False
